@@ -147,6 +147,24 @@ def cli():
     type=bool,
     help="Use custom newton solver and solve ODEs at each Newton iteration",
 )
+@click.option(
+    "--pcl",
+    default=Config.PCL,
+    type=float,
+    help="Pacing cycle length (ms)",
+)
+@click.option(
+    "--spring",
+    default=Config.spring,
+    type=float,
+    help="Set value of spring for Robin boundary condition",
+)
+@click.option(
+    "--traction",
+    default=Config.traction,
+    type=float,
+    help="Set value of traction for Neumann boundary condition",
+)
 def run(
     outdir: utils.PathLike,
     T: float,
@@ -169,6 +187,9 @@ def run(
     mechanics_ode_scheme: land_model.Scheme,
     mechanics_use_continuation: bool,
     mechanics_use_custom_newton_solver: bool,
+    pcl: float,
+    spring: float,
+    traction: float,
 ):
 
     config = Config(
@@ -177,6 +198,8 @@ def run(
         dx=dx,
         dt=dt,
         bnd_cond=bnd_cond,
+        spring=spring,
+        traction=traction,
         load_state=load_state,
         cell_init_file=cell_init_file,
         hpc=hpc,
@@ -193,6 +216,7 @@ def run(
         mechanics_ode_scheme=mechanics_ode_scheme,
         mechanics_use_continuation=mechanics_use_continuation,
         mechanics_use_custom_newton_solver=mechanics_use_custom_newton_solver,
+        PCL=pcl,
     )
     main(config=config)
 
