@@ -42,6 +42,10 @@ class Config:
     linear_mechanics_solver: str = "mumps"
     mechanics_use_continuation: bool = False
     mechanics_use_custom_newton_solver: bool = False
+    PCL: float = 1000
+
+    def as_dict(self):
+        return {k: v for k, v in self.__dict__.items()}
 
 
 def default_parameters():
