@@ -409,7 +409,8 @@ def plot_state_traces(results_file):
         residual_data = residual_file.readlines()
         residualN = []
         for line in residual_data:
-            residualN.append(float(line.strip().split("\t")[-1]))
+            if line.strip().split("\t")[-1] != "":
+                residualN.append(float(line.strip().split("\t")[-1]))
         residual_file.close()
 
         # Back to initial dt and time points
@@ -424,7 +425,6 @@ def plot_state_traces(results_file):
             color="lightcoral",
             label="Newton residualN",
         )
-        ax00r.yaxis.set_ticks([min(residualN), max(residualN)])
         ax01r = ax[0, 1].twinx()
         ax01r.plot(
             times_dt,
@@ -433,7 +433,6 @@ def plot_state_traces(results_file):
             color="lightcoral",
             label="Newton residualN",
         )
-        ax01r.yaxis.set_ticks([min(residualN), max(residualN)])
         ax01r.set_ylabel("Newton residual N")
         ax10r = ax[1, 0].twinx()
         ax10r.plot(
@@ -443,7 +442,6 @@ def plot_state_traces(results_file):
             color="lightcoral",
             label="Newton residualN",
         )
-        ax10r.yaxis.set_ticks([min(residualN), max(residualN)])
         ax11r = ax[1, 1].twinx()
         ax11r.plot(
             times_dt,
@@ -452,7 +450,6 @@ def plot_state_traces(results_file):
             color="lightcoral",
             label="Newton residualN",
         )
-        ax11r.yaxis.set_ticks([min(residualN), max(residualN)])
         ax11r.set_ylabel("Newton residual N")
         fig.tight_layout()
 
@@ -560,6 +557,12 @@ def stats(y):
     return ave, SD
 
 
+def extract_last_beat(y, time, pacing):
+    allbeats = apf.Beats(y=y, t=time, pacing=pacing)
+    lastbeat = allbeats.beats[-1]
+    return lastbeat.y, lastbeat.t
+
+
 def get_biomarkers(dict, outdir, num_models):
     biomarker_dict = {}
     fig, ax = plt.subplots()
@@ -577,6 +580,33 @@ def get_biomarkers(dict, outdir, num_models):
         for i in range(0, len(lmbda)):
             inv_lmbda[i] = 1.0 - lmbda[i]
 
+        # Select only last beat for further analysis
+        onlylastbeat = True
+        if onlylastbeat:
+            logger.info(
+                "Only extracting biomarkers for the last beat of the simulation",
+            )
+            # Create a list with pacing indicators
+            pacing = np.zeros_like(time)
+            for i in range(0, len(pacing)):
+                if time[i] % 1000 <= 0.09 or i == 0:
+                    pacing[i] = 1
+
+            # Overwrite the variables with data from only the last beat
+            V, timelb = extract_last_beat(V, time, pacing)
+            Ca, timelb = extract_last_beat(Ca, time, pacing)
+            Ta, timelb = extract_last_beat(Ta, time, pacing)
+            lmbda, timelb = extract_last_beat(lmbda, time, pacing)
+            u, timelb = extract_last_beat(u, time, pacing)
+            inv_lmbda, timelb = extract_last_beat(inv_lmbda, time, pacing)
+            time = timelb
+
+            figlast, axlast = plt.subplots()
+            axlast.plot(time, V)
+            axlast.set_xlabel("Time (ms)")
+            axlast.set_ylabel("Voltage (mV)")
+            figlast.savefig(outdir.joinpath("AP_lastbeat.png"), dpi=300)
+
         biomarker_dict[f"m{PoMm}"]["maxTa"] = np.max(Ta)
         biomarker_dict[f"m{PoMm}"]["ampTa"] = np.max(Ta) - np.min(Ta)
         biomarker_dict[f"m{PoMm}"]["APD40"] = find_duration(V, time, 40)
@@ -715,9 +745,14 @@ def save_popu_json(population_folder, num_models):
 
                         else:
                             # Otherwise, evaluation at center coordinates
-                            dict[f"m{PoMm}"][name].append(
-                                float(func(bnd[group].center)),
-                            )
+                            try:
+                                dict[f"m{PoMm}"][name].append(
+                                    float(func(bnd[group].center)),
+                                )
+                            except RuntimeError:
+                                dict[f"m{PoMm}"][name].append(
+                                    func.vector().get_local()[dof],
+                                )
 
         # Save entire dict to json file in outdir(=population_folder)
         with open(population_folder.joinpath("output_dict_center.json"), "w") as f:
